@@ -19,7 +19,7 @@ class BlogRepository:
                 postId=p['postId'], title=p['title'], videoId=p['videoId'], content=p['content'],
                 labels=p.get('labels', 0),
                 url=p.get('url', ''),
-                amara_embed=p.get('amara_embed', '')
+                amara_embed=p.get('amara_embed', ''), last_updated=datetime.utcnow()
             ) for p in self.posts_in_blog
             }
 
